@@ -50,7 +50,7 @@
 #
 gamV <- function(formula, family = gaussian(), data = list(), method = "REML", aGam = list(), aViz = list()){
   
-  obj <- do.call("gam", c(list("formula" = formula, "family" = family, "data" = data, "method" = method), aGam))
+  obj <- do.call("gam", c(list("formula" = formula, "family" = family, "data" = quote(data), "method" = method), aGam))
   
   obj <- do.call("getViz", c(list("o" = obj), aViz))
   
