@@ -4,7 +4,7 @@
 #' @export
 #'
 plot.multi.mgcv.smooth.1D <- function(x, n = 100, xlim = NULL, maxpo = 1e4, trans = identity,
-                                      unconditional = FALSE, seWithMean = FALSE, ...) {
+                                      unconditional = FALSE, seWithMean = FALSE, asFact = NULL, ...) {
   
   # 1) Prepare data
   tmp <- lapply(x, function(.inp) plot(.inp, n = n, xlim = xlim, maxpo = maxpo, trans = trans, 
@@ -17,7 +17,8 @@ plot.multi.mgcv.smooth.1D <- function(x, n = 100, xlim = NULL, maxpo = 1e4, tran
   names( P$data ) <- names( x )
   
   # 2) Produce output object
-  out <- .plot.multi.mgcv.smooth.1D(P = P, trans = trans)
+  out <- .plot.multi.mgcv.smooth.1D(P = P, trans = trans, 
+                                    asFact = asFact, isMQGAM =  attr(x, "isMQGAM"))
   
   class(out) <- c("plotSmooth", "gg")
   
@@ -26,7 +27,7 @@ plot.multi.mgcv.smooth.1D <- function(x, n = 100, xlim = NULL, maxpo = 1e4, tran
 
 ############### Internal function
 #' @noRd
-.plot.multi.mgcv.smooth.1D <- function(P = P, trans = trans) {
+.plot.multi.mgcv.smooth.1D <- function(P, trans, asFact, isMQGAM) {
   
   .fitDat <- lapply(P$data, "[[", "fit")
   
@@ -38,6 +39,9 @@ plot.multi.mgcv.smooth.1D <- function(x, n = 100, xlim = NULL, maxpo = 1e4, tran
                          "y" = as.vector( sapply(.fitDat, "[[", "y") ), 
                          "ty" = as.vector( sapply(.fitDat, "[[", "ty") ),  
                          "id" = rep(.idNam, each = length(.fitDat[[1]]$x)))
+  if( !isMQGAM ){ 
+    .dat$fit$id <- if(is.null(asFact)||asFact){ as.factor(.dat$fit$id) } else { as.numeric(.dat$fit$id) }
+  }
   
   .dat$res <- P$data[[1]]$res
   .dat$res$y <- NULL
@@ -49,6 +53,18 @@ plot.multi.mgcv.smooth.1D <- function(x, n = 100, xlim = NULL, maxpo = 1e4, tran
     theme_bw() +
     theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
   
+  if (isMQGAM){ # Setting legend for MQGAMs
+    if (is.null(asFact)){ asFact <- length(.idNam) < 10 }
+    if (asFact == TRUE) {
+       .pl <- .pl + scale_color_gradient(breaks = round(sort(.idNam, decreasing = TRUE), 3)) +
+        guides(color = guide_legend(override.aes = list(size = 5)))
+    } else {
+      if (min(diff(sort(.idNam)))>0.099) { # Ticks will be plotted if they are more than 10% apart, rounding error prevents >=0.1
+        .pl <- .pl + scale_color_gradient(breaks = sort(.idNam, decreasing = TRUE))
+      }
+    }
+  } 
+  
   return( list("ggObj" = .pl, "data" = .dat, "type" = c("Multi", "1D")) ) 
   
 }
